<?php
// خواندن مقادیر از فایل‌های متنی
$systemRole = file_get_contents('system_role.txt');
$userRole = file_get_contents('user_role.txt');
$predefinedText = file_get_contents('predefined_text.txt');
?>

<!DOCTYPE html>
<html lang="fa" dir="rtl">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>چت با هوش مصنوعی</title>
    <!-- اضافه کردن بوت‌استرپ -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
        body {
            font-family: 'Vazir', Arial, sans-serif;
            background-color: #f8f9fa;
        }
        .container {
            margin-top: 50px;
        }
        textarea {
            resize: none;
        }
        #result {
            margin-top: 20px;
        }
    </style>
</head>
<body>
    <div class="container">
        <div class="card shadow">
            <div class="card-header bg-primary text-white text-center">
                <h1>چت با هوش مصنوعی</h1>
            </div>
            <div class="card-body">
                <form id="chatForm">
                    <div class="mb-3">
                        <label for="prompt" class="form-label">سوال خود را وارد کنید:</label>
                        <textarea class="form-control" id="prompt" name="prompt" rows="4" required></textarea>
                    </div>
                    <button type="button" onclick="callGeminiApi()" class="btn btn-primary w-100">ارسال</button>
                </form>

                <div id="result" class="mt-4">
                    <h2 class="text-center">پاسخ:</h2>
                    <div id="responseHTML" class="alert alert-secondary"></div>
                    <p id="error-message" class="text-danger text-center"></p>
                </div>
            </div>
        </div>
    </div>

    <!-- اضافه کردن اسکریپت‌های بوت‌استرپ و marked.js -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/marked/marked.min.js"></script>

    <script>
        const API_KEY = 'AIzaSyA8Nh1KwZX4-vQjXrUDO3jPab-Hw95HEyM'; // کلید API خود را جایگزین کنید

        // مقادیر خوانده شده از PHP
        const systemRole = `<?php echo $systemRole; ?>`;
        const userRole = `<?php echo $userRole; ?>`;
        const predefinedText = `<?php echo $predefinedText; ?>`;

        async function callGeminiApi() {
            const promptText = document.getElementById('prompt').value;
            const responseHTMLElement = document.getElementById('responseHTML');
            const errorMessageElement = document.getElementById('error-message');

            responseHTMLElement.innerHTML = '<div class="text-center">در حال پردازش...</div>';
            errorMessageElement.textContent = '';

            const apiUrl = `https://generativelanguage.googleapis.com/v1beta/models/gemini-1.0-pro:generateContent?key=${API_KEY}`;

            try {
                const response = await fetch(apiUrl, {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/json',
                    },
                    body: JSON.stringify({
                        contents: [
                            {
                                role: "user",
                                parts: [{
                                    text: (systemRole ? `System: ${systemRole}\n` : "") + 
                                          (userRole ? `User: ${userRole}\n` : "") + 
                                          `Prompt: ${predefinedText} ${promptText}`
                                }]
                            }
                        ]
                    }),
                });

                if (!response.ok) {
                    const errorData = await response.json();
                    let errorMessage = `خطای HTTP! وضعیت: ${response.status}`;
                    if (errorData && errorData.error && errorData.error.message) {
                        errorMessage += `. خطای API: ${errorData.error.message}`;
                    }
                    throw new Error(errorMessage);
                }

                const data = await response.json();

                if (data.candidates && data.candidates.length > 0 && data.candidates[0].content && data.candidates[0].content.parts && data.candidates[0].content.parts.length > 0) {
                    const markdownResponse = data.candidates[0].content.parts[0].text;
                    const htmlResponse = marked.parse(markdownResponse);
                    responseHTMLElement.innerHTML = htmlResponse;
                } else {
                    responseHTMLElement.innerHTML = '<p class="text-center">پاسخی یافت نشد.</p>';
                }

            } catch (error) {
                console.error('خطا:', error);
                errorMessageElement.textContent = 'خطا: ' + error.message;
                responseHTMLElement.innerHTML = '';
            }
        }
    </script>
</body>
</html>